"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.testId = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _theming = require("../../core/theming");

var _styles = require("../../styles/styles");

var _ = require("../..");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const testId = 'button';
exports.testId = testId;

const Button = ({
  accessible,
  accessibilityLabel,
  active = false,
  children,
  disabled = false,
  onPress,
  onLongPress,
  primary = false,
  size = 'md',
  square = false,
  style = {},
  variant = 'default',
  theme,
  ...rest
}) => {
  const [isPressed, setIsPressed] = (0, _react.useState)(false);

  const getWidth = () => {
    return square ? _styles.blockSizes[size] : 'auto';
  };

  const isFlat = variant === 'flat';

  const getBackgroundColor = () => {
    if (isFlat) {
      return disabled ? theme.flatLight : 'transparent';
    }

    return theme.material;
  };

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, _extends({
    style: [styles.wrapper, {
      height: _styles.blockSizes[size],
      width: getWidth()
    }, style],
    testID: testId
  }, rest), /*#__PURE__*/_react.default.createElement(Borders, {
    theme: theme,
    isPressed: isPressed,
    variant: variant,
    primary: primary,
    active: active,
    style: {
      backgroundColor: getBackgroundColor()
    }
  }), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableHighlight, {
    style: [styles.content, {
      paddingHorizontal: square ? 0 : 10
    }, {
      marginTop: active || isPressed ? 2 : 0
    }],
    onPress: onPress,
    onLongPress: onLongPress,
    disabled: disabled // TODO: use onHideUnderlay or onPressIn?
    ,
    onHideUnderlay: () => setIsPressed(false),
    onShowUnderlay: () => setIsPressed(true),
    underlayColor: "none",
    accessibilityLabel: accessibilityLabel,
    accessibilityTraits: disabled ? ['button', 'disabled'] : 'button',
    accessibilityComponentType: "button",
    accessibilityRole: "button",
    accessibilityState: {
      disabled
    },
    accessible: accessible
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    pointerEvents: "none"
  }, typeof children === 'string' ? /*#__PURE__*/_react.default.createElement(_.Text, {
    disabled: !isFlat && disabled,
    secondary: isFlat && disabled
  }, children) : children)));
};

const styles = _reactNative.StyleSheet.create({
  wrapper: {
    position: 'relative'
  },
  content: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  }
});

var _default = (0, _theming.withTheme)(Button); // Borders acts like a pseudo element that
// will be positioned absolutely in it's parent element


exports.default = _default;

// TODO: pass theme as an argument instead of using context ?
const Borders = ({
  isPressed = false,
  variant = 'default',
  primary = false,
  active = false,
  style = {},
  theme
}) => {
  let wrapper = [];
  let outer;
  let inner;
  let focus;
  const borders = (0, _styles.buildBorderStyles)(theme);

  if (variant === 'default') {
    wrapper = primary ? [borders.outline] : [];
    outer = [borders.defaultOuter];
    inner = [borders.defaultInner];
    focus = isPressed ? [borders.focusOutline] : [];
  } else if (variant === 'raised') {
    wrapper = primary ? [borders.outline] : [];
    outer = [borders.outsideOuter];
    inner = [borders.outsideInner];
    focus = isPressed ? [borders.focusOutline] : [];
  } else if (variant === 'menu' && (active || isPressed)) {
    wrapper = [borders.well];
  } else if (variant === 'flat') {
    wrapper = primary ? [borders.outline] : [];
    outer = [borders.flat];
    inner = isPressed ? [borders.focusOutline] : [];
  }

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [borderStyles.position, active || isPressed ? borderStyles.invert : {}, ...wrapper, style]
  }, Array.isArray(outer) && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [borderStyles.position, ...outer]
  }, Array.isArray(inner) && inner.length > 0 && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [borderStyles.position, ...inner]
  }, Array.isArray(focus) && !active && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [borderStyles.position, {
      margin: primary ? 0 : 2
    }, ...focus]
  }), active && /*#__PURE__*/_react.default.createElement(_reactNative.ImageBackground, {
    style: [borderStyles.position],
    imageStyle: {
      resizeMode: 'repeat'
    },
    source: {
      // TODO: create util function for generating checkered background
      uri: 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAgAAAAICAYAAADED76LAAAAIUlEQVQoU2P8////fwYkwMjIyIjCp4MCZPtAbAwraa8AAEGrH/nfAIhgAAAAAElFTkSuQmCC'
    }
  }))));
};

const borderStyles = _reactNative.StyleSheet.create({
  position: {
    position: 'absolute',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  },
  invert: {
    transform: [{
      rotate: '180deg'
    }]
  }
});
//# sourceMappingURL=Button.js.map