function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useState } from 'react';
import { StyleSheet // TODO: use Pressable instead of TouchableHighlight?
, TouchableHighlight, View, ImageBackground } from 'react-native';
import { withTheme } from '../../core/theming';
import { blockSizes, buildBorderStyles } from '../../styles/styles';
import { Text } from '../..';
export const testId = 'button';

const Button = ({
  accessible,
  accessibilityLabel,
  active = false,
  children,
  disabled = false,
  onPress,
  onLongPress,
  primary = false,
  size = 'md',
  square = false,
  style = {},
  variant = 'default',
  theme,
  ...rest
}) => {
  const [isPressed, setIsPressed] = useState(false);

  const getWidth = () => {
    return square ? blockSizes[size] : 'auto';
  };

  const isFlat = variant === 'flat';

  const getBackgroundColor = () => {
    if (isFlat) {
      return disabled ? theme.flatLight : 'transparent';
    }

    return theme.material;
  };

  return /*#__PURE__*/React.createElement(View, _extends({
    style: [styles.wrapper, {
      height: blockSizes[size],
      width: getWidth()
    }, style],
    testID: testId
  }, rest), /*#__PURE__*/React.createElement(Borders, {
    theme: theme,
    isPressed: isPressed,
    variant: variant,
    primary: primary,
    active: active,
    style: {
      backgroundColor: getBackgroundColor()
    }
  }), /*#__PURE__*/React.createElement(TouchableHighlight, {
    style: [styles.content, {
      paddingHorizontal: square ? 0 : 10
    }, {
      marginTop: active || isPressed ? 2 : 0
    }],
    onPress: onPress,
    onLongPress: onLongPress,
    disabled: disabled // TODO: use onHideUnderlay or onPressIn?
    ,
    onHideUnderlay: () => setIsPressed(false),
    onShowUnderlay: () => setIsPressed(true),
    underlayColor: "none",
    accessibilityLabel: accessibilityLabel,
    accessibilityTraits: disabled ? ['button', 'disabled'] : 'button',
    accessibilityComponentType: "button",
    accessibilityRole: "button",
    accessibilityState: {
      disabled
    },
    accessible: accessible
  }, /*#__PURE__*/React.createElement(View, {
    pointerEvents: "none"
  }, typeof children === 'string' ? /*#__PURE__*/React.createElement(Text, {
    disabled: !isFlat && disabled,
    secondary: isFlat && disabled
  }, children) : children)));
};

const styles = StyleSheet.create({
  wrapper: {
    position: 'relative'
  },
  content: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  }
});
export default withTheme(Button); // Borders acts like a pseudo element that
// will be positioned absolutely in it's parent element

// TODO: pass theme as an argument instead of using context ?
const Borders = ({
  isPressed = false,
  variant = 'default',
  primary = false,
  active = false,
  style = {},
  theme
}) => {
  let wrapper = [];
  let outer;
  let inner;
  let focus;
  const borders = buildBorderStyles(theme);

  if (variant === 'default') {
    wrapper = primary ? [borders.outline] : [];
    outer = [borders.defaultOuter];
    inner = [borders.defaultInner];
    focus = isPressed ? [borders.focusOutline] : [];
  } else if (variant === 'raised') {
    wrapper = primary ? [borders.outline] : [];
    outer = [borders.outsideOuter];
    inner = [borders.outsideInner];
    focus = isPressed ? [borders.focusOutline] : [];
  } else if (variant === 'menu' && (active || isPressed)) {
    wrapper = [borders.well];
  } else if (variant === 'flat') {
    wrapper = primary ? [borders.outline] : [];
    outer = [borders.flat];
    inner = isPressed ? [borders.focusOutline] : [];
  }

  return /*#__PURE__*/React.createElement(View, {
    style: [borderStyles.position, active || isPressed ? borderStyles.invert : {}, ...wrapper, style]
  }, Array.isArray(outer) && /*#__PURE__*/React.createElement(View, {
    style: [borderStyles.position, ...outer]
  }, Array.isArray(inner) && inner.length > 0 && /*#__PURE__*/React.createElement(View, {
    style: [borderStyles.position, ...inner]
  }, Array.isArray(focus) && !active && /*#__PURE__*/React.createElement(View, {
    style: [borderStyles.position, {
      margin: primary ? 0 : 2
    }, ...focus]
  }), active && /*#__PURE__*/React.createElement(ImageBackground, {
    style: [borderStyles.position],
    imageStyle: {
      resizeMode: 'repeat'
    },
    source: {
      // TODO: create util function for generating checkered background
      uri: 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAgAAAAICAYAAADED76LAAAAIUlEQVQoU2P8////fwYkwMjIyIjCp4MCZPtAbAwraa8AAEGrH/nfAIhgAAAAAElFTkSuQmCC'
    }
  }))));
};

const borderStyles = StyleSheet.create({
  position: {
    position: 'absolute',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  },
  invert: {
    transform: [{
      rotate: '180deg'
    }]
  }
});
//# sourceMappingURL=Button.js.map