function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { View, StyleSheet } from 'react-native';
import useControlledOrUncontrolled from '../../hooks/useControlledOrUncontrolled';
import { withTheme } from '../../core/theming';
import { blockSizes } from '../../styles/styles';
import { clamp } from '../../utils';
import { TextInput, Button, ArrowIcon } from '../..';

// TODO: allow to center input text horizontally
// TODO: how are uncontrolled inputs handled in RN?
const NumberInput = ({
  defaultValue,
  disabled,
  inputWidth,
  max = null,
  min = null,
  onChange,
  step = 1,
  style = {},
  theme,
  value,
  variant = 'default',
  ...rest
}) => {
  const [valueDerived, setValueState] = useControlledOrUncontrolled({
    value,
    defaultValue
  });

  const handleClick = val => {
    const stateValue = parseFloat(valueDerived);
    const newValue = clamp(+parseFloat((stateValue + val).toString()).toFixed(2), min, max).toString();
    setValueState(parseFloat(newValue));

    if (onChange) {
      onChange(parseFloat(newValue));
    }
  };

  const valueDerivedNumber = parseFloat(valueDerived);
  const isDecrementDisabled = disabled || valueDerivedNumber === min;
  const isIncrementDisabled = disabled || valueDerivedNumber === max;
  const isFlat = variant === 'flat';
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.wrapper, style],
    accessibilityState: {
      disabled
    } // TODO: are these accessibility traits correct?
    ,
    accessibilityRole: "adjustable",
    accessibilityValue: {
      min: min === null ? undefined : min,
      max: max === null ? undefined : max,
      now: valueDerived
    }
  }, /*#__PURE__*/React.createElement(Button, {
    theme: theme,
    disabled: isDecrementDisabled,
    onPress: () => handleClick(-step),
    variant: isFlat ? 'flat' : 'raised',
    style: styles.button,
    testID: "decrement"
  }, /*#__PURE__*/React.createElement(ArrowIcon, {
    theme: theme,
    segments: 4,
    disabled: isDecrementDisabled,
    direction: "left"
  })), /*#__PURE__*/React.createElement(TextInput, _extends({
    theme: theme,
    variant: variant,
    disabled: disabled,
    value: valueDerived.toString(),
    style: [styles.input, {
      width: inputWidth || 'auto'
    }],
    editable: false // eslint-disable-next-line react/jsx-props-no-spreading
    ,
    testID: "input"
  }, rest)), /*#__PURE__*/React.createElement(Button, {
    theme: theme,
    disabled: isIncrementDisabled,
    onPress: () => handleClick(step),
    variant: isFlat ? 'flat' : 'raised',
    style: styles.button,
    testID: "increment"
  }, /*#__PURE__*/React.createElement(ArrowIcon, {
    theme: theme,
    segments: 4,
    disabled: isIncrementDisabled,
    direction: "right"
  })));
};

const styles = StyleSheet.create({
  wrapper: {
    display: 'flex',
    flexDirection: 'row',
    justifyContent: 'center'
  },
  input: {
    marginHorizontal: 2,
    minWidth: blockSizes.md + 2
  },
  button: {
    width: blockSizes.md
  },
  buttonText: {
    fontSize: 24
  }
});
export default withTheme(NumberInput);
//# sourceMappingURL=NumberInput.js.map