/* eslint-disable import/prefer-default-export */
import React from 'react';
import { StyleSheet, View } from 'react-native';
import { withTheme } from '../core/theming';
import { buildBorderStyles } from './styles';

const Border = ({
  invert = false,
  variant = 'default',
  style = {},
  sharedStyle = {},
  radius = 0,
  theme,
  children
}) => {
  const wrapper = [];
  let outer;
  let inner;
  const themedBorders = buildBorderStyles(theme);

  if (variant === 'default') {
    outer = [themedBorders.defaultOuter];
    inner = [themedBorders.defaultInner];
  } else if (variant === 'raised') {
    outer = [themedBorders.outsideOuter];
    inner = [themedBorders.outsideInner];
  } else if (variant === 'well') {
    outer = [themedBorders.well, borderStyles.invert];
  } else if (variant === 'cutout') {
    outer = [themedBorders.cutoutOuter];
    inner = [themedBorders.cutoutInner];
  } else if (variant === 'flat') {
    outer = [themedBorders.flat];
  }

  const getSharedStyles = (() => {
    let r = radius + 4;
    return () => {
      r -= 2;
      return [borderStyles.position, sharedStyle, {
        borderRadius: radius ? r : 0
      }];
    };
  })();

  return /*#__PURE__*/React.createElement(View, {
    style: [getSharedStyles(), invert ? borderStyles.invert : {}, ...wrapper, style]
  }, outer ? /*#__PURE__*/React.createElement(View, {
    style: [getSharedStyles(), ...outer]
  }, inner ? /*#__PURE__*/React.createElement(View, {
    style: [getSharedStyles(), ...inner]
  }, children) : children) : children);
};

const borderStyles = StyleSheet.create({
  position: {
    position: 'absolute',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  },
  invert: {
    transform: [{
      rotate: '180deg'
    }]
  }
});
const BorderWithTheme = withTheme(Border);
export { BorderWithTheme as Border };
//# sourceMappingURL=styleElements.js.map