import * as React from 'react';
import { Animated, StyleProp, ViewStyle, View } from 'react-native';
import type { Theme } from '../../types';
declare type Props = React.ComponentProps<typeof Animated.View> & {
    /**
     * Whether the Snackbar is currently visible.
     */
    visible: boolean;
    /**
     * Label and press callback for the action button. It should contain the following properties:
     * - `label` - Label of the action button
     * - `onPress` - Callback that is called when action button is pressed.
     */
    action?: {
        label: string;
        accessibilityLabel?: string;
        onPress: () => void;
    };
    /**
     * The duration for which the Snackbar is shown.
     */
    duration?: number;
    /**
     * Callback called when Snackbar is dismissed. The `visible` prop needs to be updated when this is called.
     */
    onDismiss: () => void;
    /**
     * Text content of the Snackbar.
     */
    children: React.ReactNode;
    /**
     * Style for the wrapper of the snackbar
     */
    wrapperStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
    ref?: React.RefObject<View>;
    /**
     * @optional
     */
    theme: Theme;
};
declare const _default: (React.ComponentClass<Pick<{
    hitSlop?: Animated.WithAnimatedValue<import("react-native").Insets | undefined> | undefined;
    onLayout?: Animated.WithAnimatedValue<((event: import("react-native").LayoutChangeEvent) => void) | undefined> | undefined;
    pointerEvents?: Animated.WithAnimatedValue<"box-none" | "none" | "box-only" | "auto" | undefined> | undefined;
    removeClippedSubviews?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    style?: Animated.WithAnimatedValue<StyleProp<ViewStyle>> | undefined;
    testID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    nativeID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    collapsable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    needsOffscreenAlphaCompositing?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    renderToHardwareTextureAndroid?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    focusable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    shouldRasterizeIOS?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    isTVSelectable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    hasTVPreferredFocus?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    tvParallaxProperties?: Animated.WithAnimatedValue<import("react-native").TVParallaxProperties | undefined> | undefined;
    tvParallaxShiftDistanceX?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxShiftDistanceY?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxTiltAngle?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxMagnification?: Animated.WithAnimatedValue<number | undefined> | undefined;
    onStartShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderGrant?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderReject?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderRelease?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderTerminationRequest?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderTerminate?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onStartShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onTouchStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchCancel?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEndCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    accessible?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityActions?: Animated.WithAnimatedValue<readonly Readonly<{
        name: import("react-native").AccessibilityActionName;
        label?: string | undefined;
    }>[] | undefined> | undefined;
    accessibilityLabel?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityRole?: Animated.WithAnimatedValue<"button" | "header" | "link" | "menu" | "menuitem" | "summary" | "image" | "switch" | "text" | "search" | "none" | "keyboardkey" | "adjustable" | "imagebutton" | "alert" | "checkbox" | "combobox" | "menubar" | "progressbar" | "radio" | "radiogroup" | "scrollbar" | "spinbutton" | "tab" | "tablist" | "timer" | "toolbar" | undefined> | undefined;
    accessibilityState?: Animated.WithAnimatedValue<import("react-native").AccessibilityState | undefined> | undefined;
    accessibilityHint?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityValue?: Animated.WithAnimatedValue<import("react-native").AccessibilityValue | undefined> | undefined;
    onAccessibilityAction?: Animated.WithAnimatedValue<((event: import("react-native").AccessibilityActionEvent) => void) | undefined> | undefined;
    accessibilityComponentType?: Animated.WithAnimatedValue<"button" | "none" | "radiobutton_checked" | "radiobutton_unchecked" | undefined> | undefined;
    accessibilityLiveRegion?: Animated.WithAnimatedValue<"none" | "polite" | "assertive" | undefined> | undefined;
    importantForAccessibility?: Animated.WithAnimatedValue<"auto" | "yes" | "no" | "no-hide-descendants" | undefined> | undefined;
    accessibilityElementsHidden?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityTraits?: Animated.WithAnimatedValue<"button" | "header" | "link" | "summary" | "image" | "text" | "search" | "none" | "adjustable" | "selected" | "plays" | "key" | "disabled" | "frequentUpdates" | "startsMedia" | "allowsDirectInteraction" | "pageTurn" | import("react-native").AccessibilityTrait[] | undefined> | undefined;
    accessibilityViewIsModal?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    onAccessibilityEscape?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onAccessibilityTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onMagicTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    accessibilityIgnoresInvertColors?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    ref?: Animated.WithAnimatedValue<((instance: View | null) => void) | React.RefObject<View> | null | undefined> | undefined;
    key?: Animated.WithAnimatedValue<string | number | null | undefined> | undefined;
} & {
    ref?: ((instance: View | {
        getNode(): View;
    } | null) => void) | React.RefObject<View | {
        getNode(): View;
    }> | null | undefined;
} & {
    /**
     * Whether the Snackbar is currently visible.
     */
    visible: boolean;
    /**
     * Label and press callback for the action button. It should contain the following properties:
     * - `label` - Label of the action button
     * - `onPress` - Callback that is called when action button is pressed.
     */
    action?: {
        label: string;
        accessibilityLabel?: string | undefined;
        onPress: () => void;
    } | undefined;
    /**
     * The duration for which the Snackbar is shown.
     */
    duration?: number | undefined;
    /**
     * Callback called when Snackbar is dismissed. The `visible` prop needs to be updated when this is called.
     */
    onDismiss: () => void;
    /**
     * Text content of the Snackbar.
     */
    children: React.ReactNode;
    /**
     * Style for the wrapper of the snackbar
     */
    wrapperStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
    ref?: React.RefObject<View> | undefined;
    /**
     * @optional
     */
    theme: Theme;
}, "ref" | "style" | "children" | "hitSlop" | "onLayout" | "pointerEvents" | "removeClippedSubviews" | "testID" | "nativeID" | "collapsable" | "needsOffscreenAlphaCompositing" | "renderToHardwareTextureAndroid" | "focusable" | "shouldRasterizeIOS" | "isTVSelectable" | "hasTVPreferredFocus" | "tvParallaxProperties" | "tvParallaxShiftDistanceX" | "tvParallaxShiftDistanceY" | "tvParallaxTiltAngle" | "tvParallaxMagnification" | "onStartShouldSetResponder" | "onMoveShouldSetResponder" | "onResponderEnd" | "onResponderGrant" | "onResponderReject" | "onResponderMove" | "onResponderRelease" | "onResponderStart" | "onResponderTerminationRequest" | "onResponderTerminate" | "onStartShouldSetResponderCapture" | "onMoveShouldSetResponderCapture" | "onTouchStart" | "onTouchMove" | "onTouchEnd" | "onTouchCancel" | "onTouchEndCapture" | "accessible" | "accessibilityActions" | "accessibilityLabel" | "accessibilityRole" | "accessibilityState" | "accessibilityHint" | "accessibilityValue" | "onAccessibilityAction" | "accessibilityComponentType" | "accessibilityLiveRegion" | "importantForAccessibility" | "accessibilityElementsHidden" | "accessibilityTraits" | "accessibilityViewIsModal" | "onAccessibilityEscape" | "onAccessibilityTap" | "onMagicTap" | "accessibilityIgnoresInvertColors" | "key" | "visible" | "action" | "duration" | "onDismiss" | "wrapperStyle"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<Theme> | undefined;
}, any> & import("@callstack/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<(React.ComponentClass<{
    hitSlop?: Animated.WithAnimatedValue<import("react-native").Insets | undefined> | undefined;
    onLayout?: Animated.WithAnimatedValue<((event: import("react-native").LayoutChangeEvent) => void) | undefined> | undefined;
    pointerEvents?: Animated.WithAnimatedValue<"box-none" | "none" | "box-only" | "auto" | undefined> | undefined;
    removeClippedSubviews?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    style?: Animated.WithAnimatedValue<StyleProp<ViewStyle>> | undefined;
    testID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    nativeID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    collapsable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    needsOffscreenAlphaCompositing?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    renderToHardwareTextureAndroid?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    focusable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    shouldRasterizeIOS?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    isTVSelectable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    hasTVPreferredFocus?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    tvParallaxProperties?: Animated.WithAnimatedValue<import("react-native").TVParallaxProperties | undefined> | undefined;
    tvParallaxShiftDistanceX?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxShiftDistanceY?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxTiltAngle?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxMagnification?: Animated.WithAnimatedValue<number | undefined> | undefined;
    onStartShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderGrant?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderReject?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderRelease?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderTerminationRequest?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderTerminate?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onStartShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onTouchStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchCancel?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEndCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    accessible?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityActions?: Animated.WithAnimatedValue<readonly Readonly<{
        name: import("react-native").AccessibilityActionName;
        label?: string | undefined;
    }>[] | undefined> | undefined;
    accessibilityLabel?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityRole?: Animated.WithAnimatedValue<"button" | "header" | "link" | "menu" | "menuitem" | "summary" | "image" | "switch" | "text" | "search" | "none" | "keyboardkey" | "adjustable" | "imagebutton" | "alert" | "checkbox" | "combobox" | "menubar" | "progressbar" | "radio" | "radiogroup" | "scrollbar" | "spinbutton" | "tab" | "tablist" | "timer" | "toolbar" | undefined> | undefined;
    accessibilityState?: Animated.WithAnimatedValue<import("react-native").AccessibilityState | undefined> | undefined;
    accessibilityHint?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityValue?: Animated.WithAnimatedValue<import("react-native").AccessibilityValue | undefined> | undefined;
    onAccessibilityAction?: Animated.WithAnimatedValue<((event: import("react-native").AccessibilityActionEvent) => void) | undefined> | undefined;
    accessibilityComponentType?: Animated.WithAnimatedValue<"button" | "none" | "radiobutton_checked" | "radiobutton_unchecked" | undefined> | undefined;
    accessibilityLiveRegion?: Animated.WithAnimatedValue<"none" | "polite" | "assertive" | undefined> | undefined;
    importantForAccessibility?: Animated.WithAnimatedValue<"auto" | "yes" | "no" | "no-hide-descendants" | undefined> | undefined;
    accessibilityElementsHidden?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityTraits?: Animated.WithAnimatedValue<"button" | "header" | "link" | "summary" | "image" | "text" | "search" | "none" | "adjustable" | "selected" | "plays" | "key" | "disabled" | "frequentUpdates" | "startsMedia" | "allowsDirectInteraction" | "pageTurn" | import("react-native").AccessibilityTrait[] | undefined> | undefined;
    accessibilityViewIsModal?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    onAccessibilityEscape?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onAccessibilityTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onMagicTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    accessibilityIgnoresInvertColors?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    ref?: Animated.WithAnimatedValue<((instance: View | null) => void) | React.RefObject<View> | null | undefined> | undefined;
    key?: Animated.WithAnimatedValue<string | number | null | undefined> | undefined;
} & {
    ref?: ((instance: View | {
        getNode(): View;
    } | null) => void) | React.RefObject<View | {
        getNode(): View;
    }> | null | undefined;
} & {
    /**
     * Whether the Snackbar is currently visible.
     */
    visible: boolean;
    /**
     * Label and press callback for the action button. It should contain the following properties:
     * - `label` - Label of the action button
     * - `onPress` - Callback that is called when action button is pressed.
     */
    action?: {
        label: string;
        accessibilityLabel?: string | undefined;
        onPress: () => void;
    } | undefined;
    /**
     * The duration for which the Snackbar is shown.
     */
    duration?: number | undefined;
    /**
     * Callback called when Snackbar is dismissed. The `visible` prop needs to be updated when this is called.
     */
    onDismiss: () => void;
    /**
     * Text content of the Snackbar.
     */
    children: React.ReactNode;
    /**
     * Style for the wrapper of the snackbar
     */
    wrapperStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
    ref?: React.RefObject<View> | undefined;
    /**
     * @optional
     */
    theme: Theme;
}, any> & {
    ({ visible, action, duration, onDismiss, children, wrapperStyle, style, theme, ...rest }: Props): JSX.Element | null;
    DURATION_SHORT: number;
    DURATION_MEDIUM: number;
    DURATION_LONG: number;
}) | (React.FunctionComponent<{
    hitSlop?: Animated.WithAnimatedValue<import("react-native").Insets | undefined> | undefined;
    onLayout?: Animated.WithAnimatedValue<((event: import("react-native").LayoutChangeEvent) => void) | undefined> | undefined;
    pointerEvents?: Animated.WithAnimatedValue<"box-none" | "none" | "box-only" | "auto" | undefined> | undefined;
    removeClippedSubviews?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    style?: Animated.WithAnimatedValue<StyleProp<ViewStyle>> | undefined;
    testID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    nativeID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    collapsable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    needsOffscreenAlphaCompositing?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    renderToHardwareTextureAndroid?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    focusable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    shouldRasterizeIOS?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    isTVSelectable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    hasTVPreferredFocus?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    tvParallaxProperties?: Animated.WithAnimatedValue<import("react-native").TVParallaxProperties | undefined> | undefined;
    tvParallaxShiftDistanceX?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxShiftDistanceY?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxTiltAngle?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxMagnification?: Animated.WithAnimatedValue<number | undefined> | undefined;
    onStartShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderGrant?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderReject?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderRelease?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderTerminationRequest?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderTerminate?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onStartShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onTouchStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchCancel?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEndCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    accessible?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityActions?: Animated.WithAnimatedValue<readonly Readonly<{
        name: import("react-native").AccessibilityActionName;
        label?: string | undefined;
    }>[] | undefined> | undefined;
    accessibilityLabel?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityRole?: Animated.WithAnimatedValue<"button" | "header" | "link" | "menu" | "menuitem" | "summary" | "image" | "switch" | "text" | "search" | "none" | "keyboardkey" | "adjustable" | "imagebutton" | "alert" | "checkbox" | "combobox" | "menubar" | "progressbar" | "radio" | "radiogroup" | "scrollbar" | "spinbutton" | "tab" | "tablist" | "timer" | "toolbar" | undefined> | undefined;
    accessibilityState?: Animated.WithAnimatedValue<import("react-native").AccessibilityState | undefined> | undefined;
    accessibilityHint?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityValue?: Animated.WithAnimatedValue<import("react-native").AccessibilityValue | undefined> | undefined;
    onAccessibilityAction?: Animated.WithAnimatedValue<((event: import("react-native").AccessibilityActionEvent) => void) | undefined> | undefined;
    accessibilityComponentType?: Animated.WithAnimatedValue<"button" | "none" | "radiobutton_checked" | "radiobutton_unchecked" | undefined> | undefined;
    accessibilityLiveRegion?: Animated.WithAnimatedValue<"none" | "polite" | "assertive" | undefined> | undefined;
    importantForAccessibility?: Animated.WithAnimatedValue<"auto" | "yes" | "no" | "no-hide-descendants" | undefined> | undefined;
    accessibilityElementsHidden?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityTraits?: Animated.WithAnimatedValue<"button" | "header" | "link" | "summary" | "image" | "text" | "search" | "none" | "adjustable" | "selected" | "plays" | "key" | "disabled" | "frequentUpdates" | "startsMedia" | "allowsDirectInteraction" | "pageTurn" | import("react-native").AccessibilityTrait[] | undefined> | undefined;
    accessibilityViewIsModal?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    onAccessibilityEscape?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onAccessibilityTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onMagicTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    accessibilityIgnoresInvertColors?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    ref?: Animated.WithAnimatedValue<((instance: View | null) => void) | React.RefObject<View> | null | undefined> | undefined;
    key?: Animated.WithAnimatedValue<string | number | null | undefined> | undefined;
} & {
    ref?: ((instance: View | {
        getNode(): View;
    } | null) => void) | React.RefObject<View | {
        getNode(): View;
    }> | null | undefined;
} & {
    /**
     * Whether the Snackbar is currently visible.
     */
    visible: boolean;
    /**
     * Label and press callback for the action button. It should contain the following properties:
     * - `label` - Label of the action button
     * - `onPress` - Callback that is called when action button is pressed.
     */
    action?: {
        label: string;
        accessibilityLabel?: string | undefined;
        onPress: () => void;
    } | undefined;
    /**
     * The duration for which the Snackbar is shown.
     */
    duration?: number | undefined;
    /**
     * Callback called when Snackbar is dismissed. The `visible` prop needs to be updated when this is called.
     */
    onDismiss: () => void;
    /**
     * Text content of the Snackbar.
     */
    children: React.ReactNode;
    /**
     * Style for the wrapper of the snackbar
     */
    wrapperStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
    ref?: React.RefObject<View> | undefined;
    /**
     * @optional
     */
    theme: Theme;
}> & {
    ({ visible, action, duration, onDismiss, children, wrapperStyle, style, theme, ...rest }: Props): JSX.Element | null;
    DURATION_SHORT: number;
    DURATION_MEDIUM: number;
    DURATION_LONG: number;
}), {}>) | (React.FunctionComponent<Pick<{
    hitSlop?: Animated.WithAnimatedValue<import("react-native").Insets | undefined> | undefined;
    onLayout?: Animated.WithAnimatedValue<((event: import("react-native").LayoutChangeEvent) => void) | undefined> | undefined;
    pointerEvents?: Animated.WithAnimatedValue<"box-none" | "none" | "box-only" | "auto" | undefined> | undefined;
    removeClippedSubviews?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    style?: Animated.WithAnimatedValue<StyleProp<ViewStyle>> | undefined;
    testID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    nativeID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    collapsable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    needsOffscreenAlphaCompositing?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    renderToHardwareTextureAndroid?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    focusable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    shouldRasterizeIOS?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    isTVSelectable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    hasTVPreferredFocus?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    tvParallaxProperties?: Animated.WithAnimatedValue<import("react-native").TVParallaxProperties | undefined> | undefined;
    tvParallaxShiftDistanceX?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxShiftDistanceY?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxTiltAngle?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxMagnification?: Animated.WithAnimatedValue<number | undefined> | undefined;
    onStartShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderGrant?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderReject?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderRelease?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderTerminationRequest?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderTerminate?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onStartShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onTouchStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchCancel?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEndCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    accessible?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityActions?: Animated.WithAnimatedValue<readonly Readonly<{
        name: import("react-native").AccessibilityActionName;
        label?: string | undefined;
    }>[] | undefined> | undefined;
    accessibilityLabel?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityRole?: Animated.WithAnimatedValue<"button" | "header" | "link" | "menu" | "menuitem" | "summary" | "image" | "switch" | "text" | "search" | "none" | "keyboardkey" | "adjustable" | "imagebutton" | "alert" | "checkbox" | "combobox" | "menubar" | "progressbar" | "radio" | "radiogroup" | "scrollbar" | "spinbutton" | "tab" | "tablist" | "timer" | "toolbar" | undefined> | undefined;
    accessibilityState?: Animated.WithAnimatedValue<import("react-native").AccessibilityState | undefined> | undefined;
    accessibilityHint?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityValue?: Animated.WithAnimatedValue<import("react-native").AccessibilityValue | undefined> | undefined;
    onAccessibilityAction?: Animated.WithAnimatedValue<((event: import("react-native").AccessibilityActionEvent) => void) | undefined> | undefined;
    accessibilityComponentType?: Animated.WithAnimatedValue<"button" | "none" | "radiobutton_checked" | "radiobutton_unchecked" | undefined> | undefined;
    accessibilityLiveRegion?: Animated.WithAnimatedValue<"none" | "polite" | "assertive" | undefined> | undefined;
    importantForAccessibility?: Animated.WithAnimatedValue<"auto" | "yes" | "no" | "no-hide-descendants" | undefined> | undefined;
    accessibilityElementsHidden?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityTraits?: Animated.WithAnimatedValue<"button" | "header" | "link" | "summary" | "image" | "text" | "search" | "none" | "adjustable" | "selected" | "plays" | "key" | "disabled" | "frequentUpdates" | "startsMedia" | "allowsDirectInteraction" | "pageTurn" | import("react-native").AccessibilityTrait[] | undefined> | undefined;
    accessibilityViewIsModal?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    onAccessibilityEscape?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onAccessibilityTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onMagicTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    accessibilityIgnoresInvertColors?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    ref?: Animated.WithAnimatedValue<((instance: View | null) => void) | React.RefObject<View> | null | undefined> | undefined;
    key?: Animated.WithAnimatedValue<string | number | null | undefined> | undefined;
} & {
    ref?: ((instance: View | {
        getNode(): View;
    } | null) => void) | React.RefObject<View | {
        getNode(): View;
    }> | null | undefined;
} & {
    /**
     * Whether the Snackbar is currently visible.
     */
    visible: boolean;
    /**
     * Label and press callback for the action button. It should contain the following properties:
     * - `label` - Label of the action button
     * - `onPress` - Callback that is called when action button is pressed.
     */
    action?: {
        label: string;
        accessibilityLabel?: string | undefined;
        onPress: () => void;
    } | undefined;
    /**
     * The duration for which the Snackbar is shown.
     */
    duration?: number | undefined;
    /**
     * Callback called when Snackbar is dismissed. The `visible` prop needs to be updated when this is called.
     */
    onDismiss: () => void;
    /**
     * Text content of the Snackbar.
     */
    children: React.ReactNode;
    /**
     * Style for the wrapper of the snackbar
     */
    wrapperStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
    ref?: React.RefObject<View> | undefined;
    /**
     * @optional
     */
    theme: Theme;
}, "ref" | "style" | "children" | "hitSlop" | "onLayout" | "pointerEvents" | "removeClippedSubviews" | "testID" | "nativeID" | "collapsable" | "needsOffscreenAlphaCompositing" | "renderToHardwareTextureAndroid" | "focusable" | "shouldRasterizeIOS" | "isTVSelectable" | "hasTVPreferredFocus" | "tvParallaxProperties" | "tvParallaxShiftDistanceX" | "tvParallaxShiftDistanceY" | "tvParallaxTiltAngle" | "tvParallaxMagnification" | "onStartShouldSetResponder" | "onMoveShouldSetResponder" | "onResponderEnd" | "onResponderGrant" | "onResponderReject" | "onResponderMove" | "onResponderRelease" | "onResponderStart" | "onResponderTerminationRequest" | "onResponderTerminate" | "onStartShouldSetResponderCapture" | "onMoveShouldSetResponderCapture" | "onTouchStart" | "onTouchMove" | "onTouchEnd" | "onTouchCancel" | "onTouchEndCapture" | "accessible" | "accessibilityActions" | "accessibilityLabel" | "accessibilityRole" | "accessibilityState" | "accessibilityHint" | "accessibilityValue" | "onAccessibilityAction" | "accessibilityComponentType" | "accessibilityLiveRegion" | "importantForAccessibility" | "accessibilityElementsHidden" | "accessibilityTraits" | "accessibilityViewIsModal" | "onAccessibilityEscape" | "onAccessibilityTap" | "onMagicTap" | "accessibilityIgnoresInvertColors" | "key" | "visible" | "action" | "duration" | "onDismiss" | "wrapperStyle"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<Theme> | undefined;
}> & import("@callstack/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<(React.ComponentClass<{
    hitSlop?: Animated.WithAnimatedValue<import("react-native").Insets | undefined> | undefined;
    onLayout?: Animated.WithAnimatedValue<((event: import("react-native").LayoutChangeEvent) => void) | undefined> | undefined;
    pointerEvents?: Animated.WithAnimatedValue<"box-none" | "none" | "box-only" | "auto" | undefined> | undefined;
    removeClippedSubviews?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    style?: Animated.WithAnimatedValue<StyleProp<ViewStyle>> | undefined;
    testID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    nativeID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    collapsable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    needsOffscreenAlphaCompositing?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    renderToHardwareTextureAndroid?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    focusable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    shouldRasterizeIOS?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    isTVSelectable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    hasTVPreferredFocus?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    tvParallaxProperties?: Animated.WithAnimatedValue<import("react-native").TVParallaxProperties | undefined> | undefined;
    tvParallaxShiftDistanceX?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxShiftDistanceY?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxTiltAngle?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxMagnification?: Animated.WithAnimatedValue<number | undefined> | undefined;
    onStartShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderGrant?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderReject?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderRelease?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderTerminationRequest?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderTerminate?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onStartShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onTouchStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchCancel?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEndCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    accessible?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityActions?: Animated.WithAnimatedValue<readonly Readonly<{
        name: import("react-native").AccessibilityActionName;
        label?: string | undefined;
    }>[] | undefined> | undefined;
    accessibilityLabel?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityRole?: Animated.WithAnimatedValue<"button" | "header" | "link" | "menu" | "menuitem" | "summary" | "image" | "switch" | "text" | "search" | "none" | "keyboardkey" | "adjustable" | "imagebutton" | "alert" | "checkbox" | "combobox" | "menubar" | "progressbar" | "radio" | "radiogroup" | "scrollbar" | "spinbutton" | "tab" | "tablist" | "timer" | "toolbar" | undefined> | undefined;
    accessibilityState?: Animated.WithAnimatedValue<import("react-native").AccessibilityState | undefined> | undefined;
    accessibilityHint?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityValue?: Animated.WithAnimatedValue<import("react-native").AccessibilityValue | undefined> | undefined;
    onAccessibilityAction?: Animated.WithAnimatedValue<((event: import("react-native").AccessibilityActionEvent) => void) | undefined> | undefined;
    accessibilityComponentType?: Animated.WithAnimatedValue<"button" | "none" | "radiobutton_checked" | "radiobutton_unchecked" | undefined> | undefined;
    accessibilityLiveRegion?: Animated.WithAnimatedValue<"none" | "polite" | "assertive" | undefined> | undefined;
    importantForAccessibility?: Animated.WithAnimatedValue<"auto" | "yes" | "no" | "no-hide-descendants" | undefined> | undefined;
    accessibilityElementsHidden?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityTraits?: Animated.WithAnimatedValue<"button" | "header" | "link" | "summary" | "image" | "text" | "search" | "none" | "adjustable" | "selected" | "plays" | "key" | "disabled" | "frequentUpdates" | "startsMedia" | "allowsDirectInteraction" | "pageTurn" | import("react-native").AccessibilityTrait[] | undefined> | undefined;
    accessibilityViewIsModal?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    onAccessibilityEscape?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onAccessibilityTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onMagicTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    accessibilityIgnoresInvertColors?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    ref?: Animated.WithAnimatedValue<((instance: View | null) => void) | React.RefObject<View> | null | undefined> | undefined;
    key?: Animated.WithAnimatedValue<string | number | null | undefined> | undefined;
} & {
    ref?: ((instance: View | {
        getNode(): View;
    } | null) => void) | React.RefObject<View | {
        getNode(): View;
    }> | null | undefined;
} & {
    /**
     * Whether the Snackbar is currently visible.
     */
    visible: boolean;
    /**
     * Label and press callback for the action button. It should contain the following properties:
     * - `label` - Label of the action button
     * - `onPress` - Callback that is called when action button is pressed.
     */
    action?: {
        label: string;
        accessibilityLabel?: string | undefined;
        onPress: () => void;
    } | undefined;
    /**
     * The duration for which the Snackbar is shown.
     */
    duration?: number | undefined;
    /**
     * Callback called when Snackbar is dismissed. The `visible` prop needs to be updated when this is called.
     */
    onDismiss: () => void;
    /**
     * Text content of the Snackbar.
     */
    children: React.ReactNode;
    /**
     * Style for the wrapper of the snackbar
     */
    wrapperStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
    ref?: React.RefObject<View> | undefined;
    /**
     * @optional
     */
    theme: Theme;
}, any> & {
    ({ visible, action, duration, onDismiss, children, wrapperStyle, style, theme, ...rest }: Props): JSX.Element | null;
    DURATION_SHORT: number;
    DURATION_MEDIUM: number;
    DURATION_LONG: number;
}) | (React.FunctionComponent<{
    hitSlop?: Animated.WithAnimatedValue<import("react-native").Insets | undefined> | undefined;
    onLayout?: Animated.WithAnimatedValue<((event: import("react-native").LayoutChangeEvent) => void) | undefined> | undefined;
    pointerEvents?: Animated.WithAnimatedValue<"box-none" | "none" | "box-only" | "auto" | undefined> | undefined;
    removeClippedSubviews?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    style?: Animated.WithAnimatedValue<StyleProp<ViewStyle>> | undefined;
    testID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    nativeID?: Animated.WithAnimatedValue<string | undefined> | undefined;
    collapsable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    needsOffscreenAlphaCompositing?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    renderToHardwareTextureAndroid?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    focusable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    shouldRasterizeIOS?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    isTVSelectable?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    hasTVPreferredFocus?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    tvParallaxProperties?: Animated.WithAnimatedValue<import("react-native").TVParallaxProperties | undefined> | undefined;
    tvParallaxShiftDistanceX?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxShiftDistanceY?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxTiltAngle?: Animated.WithAnimatedValue<number | undefined> | undefined;
    tvParallaxMagnification?: Animated.WithAnimatedValue<number | undefined> | undefined;
    onStartShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponder?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderGrant?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderReject?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderRelease?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onResponderTerminationRequest?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onResponderTerminate?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onStartShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onMoveShouldSetResponderCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => boolean) | undefined> | undefined;
    onTouchStart?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchMove?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEnd?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchCancel?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    onTouchEndCapture?: Animated.WithAnimatedValue<((event: import("react-native").GestureResponderEvent) => void) | undefined> | undefined;
    accessible?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityActions?: Animated.WithAnimatedValue<readonly Readonly<{
        name: import("react-native").AccessibilityActionName;
        label?: string | undefined;
    }>[] | undefined> | undefined;
    accessibilityLabel?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityRole?: Animated.WithAnimatedValue<"button" | "header" | "link" | "menu" | "menuitem" | "summary" | "image" | "switch" | "text" | "search" | "none" | "keyboardkey" | "adjustable" | "imagebutton" | "alert" | "checkbox" | "combobox" | "menubar" | "progressbar" | "radio" | "radiogroup" | "scrollbar" | "spinbutton" | "tab" | "tablist" | "timer" | "toolbar" | undefined> | undefined;
    accessibilityState?: Animated.WithAnimatedValue<import("react-native").AccessibilityState | undefined> | undefined;
    accessibilityHint?: Animated.WithAnimatedValue<string | undefined> | undefined;
    accessibilityValue?: Animated.WithAnimatedValue<import("react-native").AccessibilityValue | undefined> | undefined;
    onAccessibilityAction?: Animated.WithAnimatedValue<((event: import("react-native").AccessibilityActionEvent) => void) | undefined> | undefined;
    accessibilityComponentType?: Animated.WithAnimatedValue<"button" | "none" | "radiobutton_checked" | "radiobutton_unchecked" | undefined> | undefined;
    accessibilityLiveRegion?: Animated.WithAnimatedValue<"none" | "polite" | "assertive" | undefined> | undefined;
    importantForAccessibility?: Animated.WithAnimatedValue<"auto" | "yes" | "no" | "no-hide-descendants" | undefined> | undefined;
    accessibilityElementsHidden?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    accessibilityTraits?: Animated.WithAnimatedValue<"button" | "header" | "link" | "summary" | "image" | "text" | "search" | "none" | "adjustable" | "selected" | "plays" | "key" | "disabled" | "frequentUpdates" | "startsMedia" | "allowsDirectInteraction" | "pageTurn" | import("react-native").AccessibilityTrait[] | undefined> | undefined;
    accessibilityViewIsModal?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    onAccessibilityEscape?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onAccessibilityTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    onMagicTap?: Animated.WithAnimatedValue<(() => void) | undefined> | undefined;
    accessibilityIgnoresInvertColors?: Animated.WithAnimatedValue<boolean | undefined> | undefined;
    ref?: Animated.WithAnimatedValue<((instance: View | null) => void) | React.RefObject<View> | null | undefined> | undefined;
    key?: Animated.WithAnimatedValue<string | number | null | undefined> | undefined;
} & {
    ref?: ((instance: View | {
        getNode(): View;
    } | null) => void) | React.RefObject<View | {
        getNode(): View;
    }> | null | undefined;
} & {
    /**
     * Whether the Snackbar is currently visible.
     */
    visible: boolean;
    /**
     * Label and press callback for the action button. It should contain the following properties:
     * - `label` - Label of the action button
     * - `onPress` - Callback that is called when action button is pressed.
     */
    action?: {
        label: string;
        accessibilityLabel?: string | undefined;
        onPress: () => void;
    } | undefined;
    /**
     * The duration for which the Snackbar is shown.
     */
    duration?: number | undefined;
    /**
     * Callback called when Snackbar is dismissed. The `visible` prop needs to be updated when this is called.
     */
    onDismiss: () => void;
    /**
     * Text content of the Snackbar.
     */
    children: React.ReactNode;
    /**
     * Style for the wrapper of the snackbar
     */
    wrapperStyle?: StyleProp<ViewStyle>;
    style?: StyleProp<ViewStyle>;
    ref?: React.RefObject<View> | undefined;
    /**
     * @optional
     */
    theme: Theme;
}> & {
    ({ visible, action, duration, onDismiss, children, wrapperStyle, style, theme, ...rest }: Props): JSX.Element | null;
    DURATION_SHORT: number;
    DURATION_MEDIUM: number;
    DURATION_LONG: number;
}), {}>);
export default _default;
